==> legend_daq2lh5-1.0.0.tar.gz: legend_daq2lh5-1.0.0/src/daq2lh5/orca/orca_header_decoder.py <==
from __future__ import annotations

import json
import logging
import plistlib

import lgdo

from ..raw_buffer import RawBuffer, RawBufferLibrary
from .orca_base import OrcaDecoder
from .orca_header import OrcaHeader
from .orca_packet import OrcaPacket

log = logging.getLogger(__name__)


class OrcaHeaderDecoder(OrcaDecoder):
    """Decodes ORCA headers."""

    def __init__(self, header: OrcaHeader = None, **kwargs) -> None:
        if header is not None:
            log.warning("unexpected non-None header")
        super().__init__(header=header, **kwargs)
        self.header = OrcaHeader()

    def make_lgdo(self, key: int = None, size: int = None) -> lgdo.Scalar:
        return lgdo.Scalar(value="")

    def buffer_is_full(self, rb: RawBuffer) -> bool:
        return rb.loc > 0

    def decode_packet(
        self, packet: OrcaPacket, packet_id: int, rbl: RawBufferLibrary = None
    ) -> bool:
        if len(self.header.keys()) != 0:
            log.warning("got an unexpected second header")
        if packet_id != 0:
            log.warning(f"header was packet number {packet_id}")
        n_bytes = packet[1]  # word 1 is the header packet length in bytes
        as_bytes = packet[2:].tobytes()
        self.header.update(plistlib.loads(as_bytes[:n_bytes], fmt=plistlib.FMT_XML))
        if rbl is not None:
            if len(rbl) != 1 or not isinstance(rbl[0].lgdo, lgdo.Scalar):
                raise ValueError(
                    f"invalid RawBufferLibrary object: len(rbl) = {len(rbl)}, type = {type(rbl[0].lgdo)}"
                )
            else:
                rbl[0].lgdo.value = json.dumps(self.header)
                rbl[0].loc = 1
        return True  # header raw buffer is "full"

==> legend_daq2lh5-1.4.2.tar.gz: legend_daq2lh5-1.4.2/src/daq2lh5/orca/orca_header_decoder.py <==
from __future__ import annotations

import json
import logging
import plistlib

import lgdo

from ..raw_buffer import RawBufferLibrary
from .orca_base import OrcaDecoder
from .orca_header import OrcaHeader
from .orca_packet import OrcaPacket

log = logging.getLogger(__name__)


class OrcaHeaderDecoder(OrcaDecoder):
    """Decodes ORCA headers."""

    def __init__(self, header: OrcaHeader = None, **kwargs) -> None:
        if header is not None:
            log.warning("unexpected non-None header")
        super().__init__(header=header, **kwargs)
        self.header = OrcaHeader()

    def make_lgdo(self, key: int = None, size: int = None) -> lgdo.Scalar:
        return lgdo.Scalar(value="")

    def decode_packet(
        self, packet: OrcaPacket, packet_id: int, rbl: RawBufferLibrary = None
    ) -> bool:
        if len(self.header.keys()) != 0:
            log.warning("got an unexpected second header")
        if packet_id != 0:
            log.warning(f"header was packet number {packet_id}")
        n_bytes = packet[1]  # word 1 is the header packet length in bytes
        as_bytes = packet[2:].tobytes()
        self.header.update(plistlib.loads(as_bytes[:n_bytes], fmt=plistlib.FMT_XML))
        if rbl is not None:
            if len(rbl) != 1 or not isinstance(rbl[0].lgdo, lgdo.Scalar):
                raise ValueError(
                    f"invalid RawBufferLibrary object: len(rbl) = {len(rbl)}, type = {type(rbl[0].lgdo)}"
                )
            else:
                rbl[0].lgdo.value = json.dumps(self.header)
                rbl[0].loc = 1
        return True  # header raw buffer is "full"
